<?php
// $Id: hansel.switches.inc,v 1.3 2010/04/28 16:36:00 mauritsl Exp $

/**
 * @file
 * Hansel switches
 *
 * Switches from Hansel core are located in this file.
 * The definitions resides in hansel.module
 *
 * @see hansel_hansel_switch_types()
 */

/**
 * Callback for "url argument" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_url_argument_compare($arguments, $value) {
  if (empty($arguments['argument'])) {
    $arg = hansel_arg(0);
  }
  else {
    $arg = hansel_arg(((int) $arguments['argument']) - 1);
  }
  if (empty($arguments['regex'])) {
    if (empty($arguments['cs'])) {
      // Use case insensitive matching.
      return strtolower($arg) == strtolower($value);
    }
    else {
      return $arg == $value;
    }
  }
  else {
    // Backslash forward slashes
    $pattern = str_replace('/', '\\/', $value);
    $pattern = "/$pattern/s";
    if (empty($arguments['cs'])) {
      // Use case insensitive matching.
      $pattern .= 'i';
    }
    return (bool) @preg_match($pattern, $arg);
  }
}

/**
 * Callback for "url argument" switch to generate the information line.
 *
 * @param array $arguments
 * @return string
 */
function hansel_switch_url_argument_info($arguments) {
  if (empty($arguments)) {
    return '1';
  }
  return $arguments['argument'];
}

/**
 * Callback for "url argument" switch to generate the configuration form.
 *
 * @param array $arguments
 * @return array
 */
function hansel_switch_url_argument_config_form($arguments) {
  $form = array();
  
  $form['argument'] = array(
    '#type' => 'textfield',
    '#title' => t('Argument number'),
    '#default_value' => empty($arguments['argument']) ? '1' : $arguments['argument'],
    '#size' => 5,
    '#description' => t('Must be numeric. Use 1 for the first argument.'),
    '#required' => TRUE,
  );

  $form['cs'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use case sensitive matching'),
    '#default_value' => !empty($arguments['cs']),
    '#description' => t('Do not match on rule "node" when on path "Node".'),
  );

  $form['regex'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use regular expressions'),
    '#default_value' => !empty($arguments['regex']),
    '#description' => t('If enabled, all subrules are parsed as Perl compatible regular expressions.'),
  );

  $form['#validate'] = array('hansel_switch_url_arguments_config_form_validate');
  
  return hansel_switch_configure_form($form);
}

/**
 * Validate callback for the "url argument" switch configuration form.
 */
function hansel_switch_url_arguments_config_form_validate($form, &$form_state) {
  if (!preg_match('/^[1-9][0-9]?$/', $form_state['values']['argument'])) {
    form_set_error('argument', t('Argument must be a number between 1 and 99'));
  }
}

/**
 * Callback for "node id" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_node_id_compare($arguments, $value) {
  if (hansel_arg(0) == 'node' && is_numeric(hansel_arg(1))) {
    return hansel_arg(1) == $value;
  }
  return FALSE;
}

/**
 * Callback for "node id" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_node_type_compare($arguments, $value) {
  if (strtolower(hansel_arg(0)) == 'node' && is_numeric(hansel_arg(1))) {
    if ($node = node_load(hansel_arg(1))) {
      return strtolower($node->type) == strtolower($value);
    }
  }
  return FALSE;
}
